(***************************************************************************************************************************)
(*                                                                                                                         *)
(*		Zip Studio 1.3 COPYRIGHT 1993, 1994 Denis CHEVRON                                                                    *)
(*    Source File: UNZIP.PAS                                                                                               *)
(*    Description: Pascal Source file to encapsulate the UZDLL13.DLL file to provide the functionality to                  *)
(*                 Borland Pascal developers.  This version was written for BP v7.0 but contains nothing that              *)
(*                 would prohibit its adaption to earlier versions of Borland's Pascal for Windows compilesr.              *)
(*    Date:        Fri Aug 26 21:30:05 1994                                                                                *)
(*    Author:      Brad Stowers, CIS: 72733,3374                                                                           *)
(*                               Internet: brad.stowers@ix.netcom.com                                                      *)
(*                                                                                                                         *)
(***************************************************************************************************************************)
(*                                                                                                                         *)
(*		To Zip, Put UZDLL13.DLL in your applications directory and add this unit to your USES clause.                        *)
(*    By using this unit, you are NOT required to use LoadLibrary and FreeLibrary.  Simply call these parameters as you    *)
(*    would any other unit.                                                                                                *)
(***************************************************************************************************************************)

unit UnZip;

interface

uses WinTypes;

(***************************************************************************************************************************)
(* The UNZIP.INC file contains constants that will be useful when calling these functions.  By including it here, you      *)
(* don't have to include it in your own program.  Do have a look at it so that you will know what is available.            *)
(***************************************************************************************************************************)

{$I UNZIP.INC}

(* Initialization function *)
  procedure UnzipInit(YourName, Password: pChar);             { required.  If you aren't a registered user, set         }
                                                              { YourName to 'TEST' and Password to ''                   }

(* Interface setting functions *)
  function  UnzipSetMsgBoxTitle(NewTitle: pChar): boolean;	   { Set the replace dialog box title ( default = "Replace...") }
  procedure UnzipSetLanguage(Language: word);                  { Set the language for the replace dialog box }
  function  UnzipSetReceivingWindow(Wnd: hWnd): boolean;       { Set the window for notification messages }
  procedure UnzipSetBackgroundMode(BackGroundMode: boolean);   { if TRUE, activate the multitask mode ( default ) }
  function  UnzipSetReplaceText(DialogTitle,                   { Set the replace dialog box labels, used     }
                                DialogText,                    { with the LANGUAGE_NONE mode and the         }
                                YesBtn,                        { ZN_REPLACE notification message.. ** NEW! **}
                                NoBtn,
                                AlwaysBtn,
                                NeverBtn: pChar): boolean;

(* Information functions ( Zip ) *)
  function  IsFileInZip(ZIPFileName,
                        FileName: pChar): boolean;             { Return TRUE if the file is in the ZIP file ** NEW! ** }
  function  CountFileInZip(FileName: pChar): integer;          { Return number of files in this Zip File }
  function  GetFileNameFromZip(FileName: pChar;
                               FileNumber: integer): pChar;    { Return the name of the iFileNumber file in this Zip File }
  function  GetZFileOriginalSize(ZIPFilename,
                                 FileName: pChar): LongInt;    { Return the not compressed size of szFileName in octets. }
  function  GetZFileCompressedSize(ZIPFileName,
                                   FileName: pChar): LongInt;  { Return the compressed size of szFileName in octets. }
  function  GetZFileDate(ZIPFileName, FileName: pChar): pChar; { Return the date of a file in a Zip }
  function  GetZFileTime(ZIPFileName, FileName: pChar): pChar; { Return the time of a file in a Zip }
  function  GetZCompressedMethod(ZIPFileName,
                                 FileName: pChar): Word;       { Return the Zip method for a file ( ZMETHOD_* ) }
  function  IsThisFileAZipFile(FileName: pChar): boolean;      { Return TRUE if this file seems to be a zip file }
  function  IsFileUnzipable(FileName: pChar): boolean;         { Return TRUE if this file name can be reproduce under DOS }
  function  GetZipCommentLength(FileName: pChar): word;        { Return the size of the zip file comment in octets }
  function  GetZipComment(FileName, Buffer: pChar): boolean;   { Put the zip comment in buffer }

(* Information functions ( General ) *)
  function DoesFileExist(FileName: pChar): boolean;            { True if this file exists }
  function GetShortFileName(FileName: pChar): pChar;           { Return filename without any path }
  function GetPathFromFileName(FileName: pChar): pChar;        { Return the path without the file name }
  function IsFileNameInFilter(FileName, Mask: pChar): boolean; { Return TRUE if filename is in specified filter }

(* Extraction functions *)
  function ExtractZipFiles(FileName, Mask,DestDir: pChar;
                           Overwrite: word;
                           CreateDir: word): word;             { Go get them }
  function GetQueryFlag: integer;                              { Return the overwrite mode the user asked for }

(* View function *)
  function ViewFileFromZip(ZipFile, Mask: pChar;
                           TextOnly: boolean): boolean;        { View one or several files in a Zip }

implementation

  procedure UnzipInit;                                         external 'UZDLL13';
  function  UnzipSetMsgBoxTitle;                               external 'UZDLL13';
  procedure UnzipSetLanguage;                                  external 'UZDLL13';
  function  UnzipSetReceivingWindow;                           external 'UZDLL13';
  procedure UnzipSetBackgroundMode;                            external 'UZDLL13';
  function  UnzipSetReplaceText;                               external 'UZDLL13';
  function  IsFileInZip;                                       external 'UZDLL13';
  function  CountFileInZip;                                    external 'UZDLL13';
  function  GetFileNameFromZip;                                external 'UZDLL13';
  function  GetZFileOriginalSize;                              external 'UZDLL13';
  function  GetZFileCompressedSize;                            external 'UZDLL13';
  function  GetZFileDate;                                      external 'UZDLL13';
  function  GetZFileTime;                                      external 'UZDLL13';
  function  GetZCompressedMethod;                              external 'UZDLL13';
  function  IsThisFileAZipFile;                                external 'UZDLL13';
  function  IsFileUnzipable;                                   external 'UZDLL13';
  function  GetZipCommentLength;                               external 'UZDLL13';
  function  GetZipComment;                                     external 'UZDLL13';
  function  DoesFileExist;                                     external 'UZDLL13';
  function  GetShortFileName;                                  external 'UZDLL13';
  function  GetPathFromFileName;                               external 'UZDLL13';
  function  IsFileNameInFilter;                                external 'UZDLL13';
  function  ExtractZipFiles;                                   external 'UZDLL13';
  function  GetQueryFlag;                                      external 'UZDLL13';
  function  ViewFileFromZip;                                   external 'UZDLL13';

end.